@@ -120,7 +120,7 @@ g2_addfield(unsigned char *cgrib, g2int ipdsnum, g2int *ipdstmpl,
 
     /* Check for GRIB header and terminator. Translate the error codes
      * to the legacy G2 error codes. */
-    if ((ret = g2c_check_msg(cgrib, &lencurr, 1)))
+    if ((ret = g2c_check_msg(cgrib, &lencurr, 1, 3)))
     {
         if (ret == G2C_ENOTGRIB)
             return G2_ADD_MSG_INIT;
