@@ -47,7 +47,7 @@ g2_addlocal(unsigned char *cgrib, unsigned char *csec2, g2int lcsec2)
 
     /* Check for GRIB header and terminator. Translate the error codes
      * to the legacy G2 error codes. */
-    if ((ret = g2c_check_msg(cgrib, &lencurr, 1)))
+    if ((ret = g2c_check_msg(cgrib, &lencurr, 1, 1)))
     {
         if (ret == G2C_ENOTGRIB)
             return G2_ADD_MSG_INIT;
