@@ -908,10 +908,10 @@ static G2C_PARAM_T param[G2C_MAX_NOAA_PARAMS] = {
     {255, 255, 2, 3, 21, "SOILICE"},
     {255, 255, 2, 3, 22, "CISICE"},
     {255, 255, 2, 3, 23, "LWSNWP"},
-    {255, 255, 2, 3, 23, "FRSTINX"},
-    {255, 255, 2, 3, 23, "SNWDEB"},
-    {255, 255, 2, 3, 23, "SHFLX"},
-    {255, 255, 2, 3, 23, "SOILDEP"},
+    {255, 255, 2, 3, 24, "FRSTINX"},
+    {255, 255, 2, 3, 25, "SNWDEB"},
+    {255, 255, 2, 3, 26, "SHFLX"},
+    {255, 255, 2, 3, 27, "SOILDEP"},
     {255, 255, 2, 4, 0, "FIREOLK"},
     {255, 255, 2, 4, 1, "FIREODT"},
     {255, 255, 2, 4, 3, "FBAREA"},
@@ -1026,7 +1026,346 @@ static G2C_PARAM_T param[G2C_MAX_NOAA_PARAMS] = {
     {240, 129, 0, 16, 3, "RETOP"},
     {234, 2, 1, 0, 5, "BGRUN"},
     {235, 2, 1, 0, 6, "SSRUN"},
-    {160, 130, 2, 3, 5, "SOILL"}};
+    {160, 130, 2, 3, 5, "SOILL"},
+    {255, 255, 0, 21, 0, "POTINTENG"},
+    {255, 255, 0, 21, 1, "KINENG"},
+    {255, 255, 0, 21, 2, "TOTENG"},
+    {255, 255, 0, 21, 3, "ENTHALPY"},
+    {255, 255, 0, 21, 4, "WATENTHALPY"},
+    {255, 255, 0, 21, 5, "EASTENTFLUX"},
+    {255, 255, 0, 21, 6, "NRTHENTFLUX"},
+    {255, 255, 0, 21, 7, "EASTPOTFLUX"},
+    {255, 255, 0, 21, 8, "NRTHPOTFLUX"},
+    {255, 255, 0, 21, 9, "EASTKINFLUX"},
+    {255, 255, 0, 21, 10, "NRTHKINFLUX"},
+    {255, 255, 0, 21, 11, "EASTTOTFLUX"},
+    {255, 255, 0, 21, 12, "NRTHTOTFLUX"},
+    {255, 255, 0, 21, 13, "DIVENTFLUX"},
+    {255, 255, 0, 21, 14, "DIVPOTFLUX"},
+    {255, 255, 0, 21, 15, "DIVWPOTFLUX"},
+    {255, 255, 0, 21, 16, "DIVKENGFLUX"},
+    {255, 255, 0, 21, 17, "DIVTOTFLUX"},
+    {255, 255, 0, 21, 18, "DIVWENTFLUX"},
+    {255, 255, 0, 21, 19, "EASTHFLUX"},
+    {255, 255, 0, 21, 20, "NRTHHFLUX"},
+    {255, 255, 0, 21, 21, "PILENERGY"},
+    {255, 255, 0, 21, 22, "EADYGR"},
+    {255, 255, 0, 22, 0, "SPI"},
+    {255, 255, 0, 22, 1, "SPEI"},
+    {255, 255, 0, 22, 2, "SSFI"},
+    {255, 255, 0, 22, 3, "SRSI"},
+    {255, 255, 0, 22, 4, "SWI"},
+    {255, 255, 0, 22, 5, "SMRI"},
+    {255, 255, 0, 22, 6, "SDI"},
+    {255, 255, 2, 6, 0, "URBCOVER"},
+    {255, 255, 2, 6, 1, "ROADCOVER"},
+    {255, 255, 2, 6, 2, "BUILDCOVER"},
+    {255, 255, 2, 6, 3, "BUILDHGT"},
+    {255, 255, 2, 6, 4, "VZAFRAC"},
+    {255, 255, 2, 6, 5, "SDBUILDHGT"},
+    {255, 255, 2, 6, 6, "DDROOF"},
+    {255, 255, 2, 6, 7, "DIOWALL"},
+    {255, 255, 2, 6, 8, "DDROAD"},
+    {255, 255, 0, 0, 205, "ELMELT"},
+    {255, 255, 0, 0, 206, "WETGLBT"},
+    {255, 255, 0, 1, 122, "PIIDX"},
+    {255, 255, 0, 1, 123, "DPTYPE"},
+    {255, 255, 0, 1, 124, "PSHOW"},
+    {255, 255, 0, 1, 125, "PBSNOW"},
+    {255, 255, 0, 1, 126, "PBLIZZ"},
+    {255, 255, 0, 1, 127, "ICEP"},
+    {255, 255, 0, 1, 128, "TSPRATE"},
+    {255, 255, 0, 1, 147, "CHPRECIP"},
+    {255, 255, 0, 1, 150, "CEWVMF"},
+    {255, 255, 0, 1, 151, "CNWVMF"},
+    {255, 255, 0, 1, 152, "CECLWMF"},
+    {255, 255, 0, 1, 153, "CNCLWMF"},
+    {255, 255, 0, 1, 154, "CECIMF"},
+    {255, 255, 0, 1, 155, "CNCIMF"},
+    {255, 255, 0, 1, 156, "CERMF"},
+    {255, 255, 0, 1, 157, "CNRMF"},
+    {255, 255, 0, 1, 158, "CEFMF"},
+    {255, 255, 0, 1, 159, "CNSMF"},
+    {255, 255, 0, 1, 160, "CDWFMF"},
+    {255, 255, 0, 1, 161, "CDCLWMF"},
+    {255, 255, 0, 1, 162, "CDCIMF"},
+    {255, 255, 0, 1, 163, "CDRMF"},
+    {255, 255, 0, 1, 164, "CDSMF"},
+    {255, 255, 0, 1, 165, "CDTWMF"},
+    {255, 255, 0, 1, 166, "CWVF"},
+    {255, 255, 0, 1, 167, "TCSLW"},
+    {255, 255, 0, 1, 168, "SSPFHW"},
+    {255, 255, 0, 1, 169, "TCISSPFHW"},
+    {255, 255, 0, 2, 47, "SFRHEAT"},
+    {255, 255, 0, 2, 48, "SFRMOIST"},
+    {255, 255, 0, 2, 49, "WINDSTR"},
+    {255, 255, 0, 2, 50, "EWINDSTR"},
+    {255, 255, 0, 2, 51, "NWINDSTR"},
+    {255, 255, 0, 2, 52, "UWINDSTR"},
+    {255, 255, 0, 2, 53, "VWINDSTR"},
+    {255, 255, 0, 2, 54, "NLSRLH"},
+    {255, 255, 0, 2, 55, "NLSRLM"},
+    {255, 255, 0, 2, 56, "UNWIND"},
+    {255, 255, 0, 2, 57, "VNWIND"},
+    {255, 255, 0, 2, 58, "TSFCSTR"},
+    {255, 255, 0, 2, 59, "VDIV"},
+    {255, 255, 0, 2, 60, "DTC"},
+    {255, 255, 0, 2, 61, "DEC"},
+    {255, 255, 0, 2, 62, "EASTTSS"},
+    {255, 255, 0, 2, 63, "NRTHTSS"},
+    {255, 255, 0, 2, 64, "EASTTSSOD"},
+    {255, 255, 0, 2, 65, "NRTHTSSOD"},
+    {255, 255, 0, 2, 66, "EASTTSSSR"},
+    {255, 255, 0, 2, 67, "NRTHTSSSR"},
+    {255, 255, 0, 3, 32, "SWATERVP"},
+    {255, 255, 0, 3, 33, "GAMSL"},
+    {255, 255, 0, 3, 34, "GHAGRD"},
+    {255, 255, 0, 3, 35, "CDTMF"},
+    {255, 255, 0, 3, 36, "CETMF"},
+    {255, 255, 0, 3, 37, "CNTMF"},
+    {255, 255, 0, 3, 38, "SDFSO"},
+    {255, 255, 0, 3, 39, "CMATMOS"},
+    {255, 255, 0, 3, 40, "CEGFLUX"},
+    {255, 255, 0, 3, 41, "CNGFLUX"},
+    {255, 255, 0, 3, 42, "CDWGFLUX"},
+    {255, 255, 0, 3, 43, "CDGFLUX"},
+    {255, 255, 0, 3, 44, "HWBT"},
+    {255, 255, 0, 3, 45, "WOBT"},
+    {255, 255, 0, 3, 46, "PRESDHS"},
+    {255, 255, 0, 3, 222, "EFSH"},
+    {255, 255, 0, 4, 15, "UVVEARTH"},
+    {255, 255, 0, 4, 53, "USWRFCS"},
+    {255, 255, 0, 4, 54, "DNSWRFLX"},
+    {255, 255, 0, 4, 55, "UVALBDIF"},
+    {255, 255, 0, 4, 56, "UVALBDIR"},
+    {255, 255, 0, 4, 57, "UBALBDIRG"},
+    {255, 255, 0, 4, 58, "UVALBDIRI"},
+    {255, 255, 0, 4, 59, "UVBDIRV"},
+    {255, 255, 0, 4, 60, "PHOARFCS"},
+    {255, 255, 0, 4, 61, "DSWRFLXCS"},
+    {255, 255, 0, 5, 9, "NIRALBDIF"},
+    {255, 255, 0, 5, 10, "NIRALBDIR"},
+    {255, 255, 0, 5, 11, "NIRALBDIRG"},
+    {255, 255, 0, 5, 12, "NIRALBDIRI"},
+    {255, 255, 0, 5, 13, "NIRALBDIRV"},
+    {255, 255, 0, 6, 50, "FOG"},
+    {255, 255, 0, 6, 51, "SUNFRAC"},
+    {255, 255, 0, 7, 20, "TIIDEX"},
+    {255, 255, 0, 7, 207, "E3KH"},
+    {255, 255, 0, 7, 208, "STPC"},
+    {255, 255, 0, 7, 209, "SIGH"},
+    {255, 255, 0, 7, 210, "SCCP"},
+    {255, 255, 0, 7, 211, "SIGT"},
+    {255, 255, 0, 7, 212, "MLFC"},
+    {255, 255, 0, 14, 204, "ALD2"},
+    {255, 255, 0, 17, 5, "SLNGPIDX"},
+    {255, 255, 0, 18, 19, "DEPACTA"},
+    {255, 255, 0, 18, 20, "DEPACTE"},
+    {255, 255, 0, 18, 21, "CLDACTA"},
+    {255, 255, 0, 18, 22, "CLDACTE"},
+    {255, 255, 0, 18, 23, "EFFDOSER"},
+    {255, 255, 0, 18, 24, "THYDOSER"},
+    {255, 255, 0, 18, 25, "GAMDOSER"},
+    {255, 255, 0, 18, 26, "ACTEMM"},
+    {255, 255, 0, 19, 38, "SKYIDX"},
+    {255, 255, 0, 19, 39, "SEEINDEX"},
+    {255, 255, 0, 19, 40, "SNOWLVL"},
+    {255, 255, 0, 19, 41, "DBHEIGHT"},
+    {255, 255, 0, 19, 42, "TLBHEIGHT"},
+    {255, 255, 0, 19, 43, "TLTHEIGHT"},
+    {255, 255, 0, 19, 44, "MEANVGRTL"},
+    {255, 255, 0, 19, 45, "MINVGRTL"},
+    {255, 255, 0, 19, 46, "NETRADFLUX"},
+    {255, 255, 0, 19, 47, "GLIRRTS"},
+    {255, 255, 0, 19, 48, "PCONTT"},
+    {255, 255, 0, 19, 49, "PCONTB"},
+    {255, 255, 0, 19, 50, "CITEDR"},
+    {255, 255, 0, 20, 18, "POTHPH"},
+    {255, 255, 0, 20, 78, "CEMF"},
+    {255, 255, 0, 20, 79, "CNMF"},
+    {255, 255, 0, 20, 80, "CDIVMF"},
+    {255, 255, 0, 20, 81, "CNETS"},
+    {255, 255, 0, 191, 4, "TCDTRACK"},
+    {255, 255, 0, 191, 5, "HURTSV"},
+    {255, 255, 0, 191, 6, "TSTSV"},
+    {255, 255, 0, 191, 7, "TDTSV"},
+    {255, 255, 1, 0, 17, "RVEROW"},
+    {255, 255, 1, 0, 18, "FLDPOW"},
+    {255, 255, 1, 0, 19, "FLDPATHOW"},
+    {255, 255, 1, 0, 20, "WATSURF"},
+    {255, 255, 1, 0, 194, "FHO"},
+    {255, 255, 1, 0, 196, "AHD"},
+    {255, 255, 1, 1, 196, "QPFARI"},
+    {255, 255, 1, 1, 197, "QPFFFG"},
+    {255, 255, 1, 2, 14, "LNDSNOWT"},
+    {255, 255, 1, 2, 15, "LDEPTH"},
+    {255, 255, 1, 2, 16, "RDEPTH"},
+    {255, 255, 1, 2, 17, "FLDPDEPTH"},
+    {255, 255, 1, 2, 18, "FLDPFLFR"},
+    {255, 255, 1, 2, 19, "FLDPFLAR"},
+    {255, 255, 1, 2, 20, "RVERFR"},
+    {255, 255, 1, 2, 21, "RVERAR"},
+    {255, 255, 1, 2, 22, "FRCRF"},
+    {255, 255, 1, 2, 23, "ARCRF"},
+    {255, 255, 2, 0, 40, "PEVAPTRAT"},
+    {255, 255, 2, 0, 41, "SMRATE"},
+    {255, 255, 2, 0, 42, "WRDRATE"},
+    {255, 255, 2, 0, 43, "DRAINDIR"},
+    {255, 255, 2, 0, 44, "UPSAREA"},
+    {255, 255, 2, 0, 45, "WETCOV"},
+    {255, 255, 2, 0, 46, "WETTYPE"},
+    {255, 255, 2, 0, 47, "IRRCOV"},
+    {255, 255, 2, 0, 48, "CROPCOV"},
+    {255, 255, 2, 0, 49, "GRASSCOV"},
+    {255, 255, 2, 0, 50, "SKINRC"},
+    {255, 255, 2, 0, 51, "SURFRATE"},
+    {255, 255, 2, 0, 52, "SUBSRATE"},
+    {255, 255, 2, 0, 53, "LOVEGCOV"},
+    {255, 255, 2, 0, 54, "HIVEGCOV"},
+    {255, 255, 2, 0, 55, "LAILO"},
+    {255, 255, 2, 0, 56, "LAIHI"},
+    {255, 255, 2, 0, 57, "TYPLOVEG"},
+    {255, 255, 2, 0, 58, "TYPHIVEG"},
+    {255, 255, 2, 0, 59, "NECOFLUX"},
+    {255, 255, 2, 0, 60, "GROSSFLUX"},
+    {255, 255, 2, 0, 61, "ECORFLUX"},
+    {255, 255, 2, 0, 62, "EMISS"},
+    {255, 255, 2, 0, 63, "CANTMP"},
+    {255, 255, 2, 0, 233, "LANDFRC"},
+    {255, 255, 2, 0, 234, "LAKEFRC"},
+    {255, 255, 2, 0, 235, "PAHFLX"},
+    {255, 255, 2, 0, 236, "WATERSA"},
+    {255, 255, 2, 0, 237, "EIWATER"},
+    {255, 255, 2, 0, 238, "PLANTTR"},
+    {255, 255, 2, 0, 239, "SOILSE"},
+    {255, 255, 2, 3, 28, "SNOWTMP"},
+    {255, 255, 2, 3, 29, "ICETEMP"},
+    {255, 255, 2, 3, 30, "SWET"},
+    {255, 255, 2, 3, 204, "MSTAVTOP"},
+    {255, 255, 2, 4, 20, "BURNAREA"},
+    {255, 255, 2, 4, 21, "BURNABAREA"},
+    {255, 255, 2, 4, 22, "UNBURNAREA"},
+    {255, 255, 2, 4, 23, "FUELLOAD"},
+    {255, 255, 2, 4, 24, "COMBCO"},
+    {255, 255, 2, 4, 25, "FUELMC"},
+    {255, 255, 2, 4, 26, "WFIREPOT"},
+    {255, 255, 2, 4, 27, "LLFL"},
+    {255, 255, 2, 4, 28, "LWFL"},
+    {255, 255, 2, 4, 29, "DLFL"},
+    {255, 255, 2, 4, 30, "DWFL"},
+    {255, 255, 2, 4, 31, "LFMC"},
+    {255, 255, 2, 4, 32, "FDLMC"},
+    {255, 255, 2, 4, 33, "DDLMC"},
+    {255, 255, 2, 4, 34, "FDWMC"},
+    {255, 255, 2, 4, 35, "DDWMC"},
+    {255, 255, 2, 4, 36, "FRADPOW"},
+    {255, 255, 3, 1, 30, "RFL04"},
+    {255, 255, 3, 1, 31, "CLDREF"},
+    {255, 255, 3, 1, 32, "CLRREF"},
+    {255, 255, 3, 3, 0, "PBMVFRC"},
+    {255, 255, 3, 3, 1, "PBLIFRC"},
+    {255, 255, 3, 3, 2, "PBINFRC"},
+    {255, 255, 3, 5, 0, "ISSTMP"},
+    {255, 255, 3, 5, 1, "SKSSTMP"},
+    {255, 255, 3, 5, 2, "SSKSSTMP"},
+    {255, 255, 3, 5, 3, "FDNSSTMP"},
+    {255, 255, 3, 5, 4, "EBSSTSTD"},
+    {255, 255, 3, 5, 5, "EBSDSSTS"},
+    {255, 255, 3, 192, 86, "SSMS1712"},
+    {255, 255, 3, 192, 87, "SSMS1713"},
+    {255, 255, 10, 0, 65, "PWPFSPAR"},
+    {255, 255, 10, 0, 66, "PWPSSPAR"},
+    {255, 255, 10, 0, 67, "PWPTSPAR"},
+    {255, 255, 10, 0, 68, "PWDFSPAR"},
+    {255, 255, 10, 0, 69, "PWDSSPAR"},
+    {255, 255, 10, 0, 70, "PWDTSPAR"},
+    {255, 255, 10, 0, 71, "PDWWAVE"},
+    {255, 255, 10, 0, 72, "PDTSWELL"},
+    {255, 255, 10, 0, 73, "WCAPFRAC"},
+    {255, 255, 10, 0, 74, "MDTSWEL"},
+    {255, 255, 10, 0, 75, "MDWWAVE"},
+    {255, 255, 10, 0, 76, "CHNCK"},
+    {255, 255, 10, 0, 77, "WAVESPSK"},
+    {255, 255, 10, 0, 78, "WAVEFMAG"},
+    {255, 255, 10, 0, 79, "WAVEFDIR"},
+    {255, 255, 10, 0, 80, "RWAVEAFW"},
+    {255, 255, 10, 0, 81, "FCVOCEAN"},
+    {255, 255, 10, 0, 82, "AIRDENOC"},
+    {255, 255, 10, 0, 83, "NEFW"},
+    {255, 255, 10, 0, 84, "NSOCEAN"},
+    {255, 255, 10, 0, 85, "NEFOCEAN"},
+    {255, 255, 10, 0, 86, "SEVWAVE"},
+    {255, 255, 10, 0, 87, "WAVEMSLC"},
+    {255, 255, 10, 0, 88, "SPECWI"},
+    {255, 255, 10, 0, 89, "EFWS"},
+    {255, 255, 10, 0, 90, "USMFO"},
+    {255, 255, 10, 0, 91, "VSMFO"},
+    {255, 255, 10, 0, 92, "WAVETEFO"},
+    {255, 255, 10, 0, 93, "EMIWAVE"},
+    {255, 255, 10, 0, 94, "TDMCREST"},
+    {255, 255, 10, 0, 95, "TDMWAVE"},
+    {255, 255, 10, 0, 96, "STMCREST"},
+    {255, 255, 10, 0, 97, "STMWAVE"},
+    {255, 255, 10, 0, 98, "GODAPEAK"},
+    {255, 255, 10, 1, 5, "EASTCUR"},
+    {255, 255, 10, 1, 6, "NRTHCUR"},
+    {255, 255, 10, 2, 14, "ALBDOICE"},
+    {255, 255, 10, 2, 15, "SICEVOL"},
+    {255, 255, 10, 2, 16, "SNVOLSI"},
+    {255, 255, 10, 2, 17, "SICEHC"},
+    {255, 255, 10, 2, 18, "SNCEHC"},
+    {255, 255, 10, 2, 19, "ICEFTHCK"},
+    {255, 255, 10, 2, 20, "ICEMPF"},
+    {255, 255, 10, 2, 21, "ICEMPD"},
+    {255, 255, 10, 2, 22, "ICEMPV"},
+    {255, 255, 10, 2, 23, "SIFTP"},
+    {255, 255, 10, 2, 24, "XICE"},
+    {255, 255, 10, 2, 25, "YICE"},
+    {255, 255, 10, 2, 27, "FRZMLTPOT"},
+    {255, 255, 10, 2, 28, "MLTDATE"},
+    {255, 255, 10, 2, 29, "FRZDATE"},
+    {255, 255, 10, 3, 4, "DWHFLUX"},
+    {255, 255, 10, 3, 5, "EASTWSS"},
+    {255, 255, 10, 3, 6, "NORTHWSS"},
+    {255, 255, 10, 3, 7, "XCOMPSS"},
+    {255, 255, 10, 3, 8, "YCOMPSS"},
+    {255, 255, 10, 3, 9, "THERCSSH"},
+    {255, 255, 10, 3, 10, "HALOCSSH"},
+    {255, 255, 10, 3, 11, "STERCSSH"},
+    {255, 255, 10, 3, 12, "SEASFLUX"},
+    {255, 255, 10, 3, 13, "NETUPWFLUX"},
+    {255, 255, 10, 3, 14, "ESURFWVEL"},
+    {255, 255, 10, 3, 15, "NSURFWVEL"},
+    {255, 255, 10, 3, 16, "XSURFWVEL"},
+    {255, 255, 10, 3, 17, "YSURFWVEL"},
+    {255, 255, 10, 3, 18, "HFLUXCOR"},
+    {255, 255, 10, 3, 19, "SSHGTPARM"},
+    {255, 255, 10, 3, 20, "DSLIBARCOR"},
+    {255, 255, 10, 3, 21, "SALINITY"},
+    {255, 255, 10, 4, 29, "BPEH"},
+    {255, 255, 10, 4, 30, "FWFSW"},
+    {255, 255, 10, 4, 31, "FWFC"},
+    {255, 255, 10, 4, 32, "VSFSW"},
+    {255, 255, 10, 4, 33, "VSFC"},
+    {255, 255, 10, 4, 34, "SWTTNR"},
+    {255, 255, 10, 4, 35, "SWSTNR"},
+    {255, 255, 10, 4, 36, "SWTTP"},
+    {255, 255, 10, 4, 37, "SWSTP"},
+    {255, 255, 10, 4, 38, "ESWVP"},
+    {255, 255, 10, 4, 39, "NSWVP"},
+    {255, 255, 10, 4, 40, "SWTTBC"},
+    {255, 255, 10, 4, 41, "SWSTBC"},
+    {255, 255, 10, 4, 42, "SEAMVT"},
+    {255, 255, 10, 4, 43, "SEAZVT"},
+    {255, 255, 10, 4, 44, "SEACMVT"},
+    {255, 255, 10, 4, 45, "SEACZVT"},
+    {255, 255, 10, 4, 46, "SEAMMT"},
+    {255, 255, 10, 4, 47, "SEAZMT"},
+    {255, 255, 10, 4, 48, "SEACMMT"},
+    {255, 255, 10, 4, 49, "SEACZMT"},
+    {255, 255, 10, 4, 50, "SEACPSALT"},
+    {255, 255, 10, 4, 51, "SEACSALT"},
+    {255, 255, 10, 191, 4, "BARDSF"}};
 
 /**
  * Translate GRIB1 parameter to GRIB2 parameter.
