@@ -1829,3 +1829,38 @@ g2c_get_pds_template(int pds_template_num, int *maplen, int *map, int *needext)
     /* If we didn't find a template, return an error. */
     return G2C_ENOTEMPLATE;
 }
+
+/**
+ * Get initial length (number of entries) in static part of 
+ * PDS template.
+ *
+ * @param pds_template_num The PDS template number.
+ * @param maplen Pointer that gets the length of the map. Ignored if
+ * NULL.
+ *
+ * @return
+ * - ::G2C_NOERROR No error.
+ * - ::G2C_ENOTEMPLATE Template not found.
+ *
+ * @author Alyson Stahl @date 01/21/25
+ */
+int
+g2c_get_pdt_len(int pds_template_num, int *maplen)
+{
+    int j;
+
+    /* Look through the array of templates to find a matching one. */
+    for (j = 0; j < G2C_MAX_PDS_TEMPLATE; j++)
+    {
+        if (pds_template_num == templatespds[j].template_num)
+        {
+            if (maplen)
+                *maplen = templatespds[j].mappdslen;
+
+            return G2C_NOERROR;
+        }
+    }
+
+    /* If we didn't find a template, return an error. */
+    return G2C_ENOTEMPLATE;
+}
\ No newline at end of file
